@@ -11,13 +11,15 @@ class BlueprintBuilder:
     def __init__(
         self, 
         layers: list[str], 
+        base_path: str, 
         base_schema: dict={},
         exclusion_table: dict={},
         inclusion_table: dict={},
         sub_traits_z_vals: dict={},
         rarity_table: dict={}
     ) -> None:
-        self.layers = self.__layers__(layers, sub_traits_z_vals, rarity_table)
+        self.base_path = base_path
+        self.layers = self.__layers__(layers, base_path, sub_traits_z_vals, rarity_table)
         self.schema = self.__schema__(base_schema)
         self.exclusion_table = exclusion_table
         self.inclusion_table = inclusion_table
@@ -28,6 +30,7 @@ class BlueprintBuilder:
     def __layers__(
         self, 
         layers: list[str], 
+        base_path: str, 
         sub_traits_z_vals: dict,
         rarity_table: dict
     ) -> list[Layer]:
@@ -35,7 +38,7 @@ class BlueprintBuilder:
             Layer(
                 layers[i], 
                 float(i), 
-                "", 
+                base_path, 
                 sub_trait_z_vals=sub_traits_z_vals,
                 rarity_table=rarity_table
             ) for i in range(len(layers))
@@ -50,8 +53,20 @@ class BlueprintBuilder:
         return schema
 
     def __inclusions__(self):
-        #TODO:
-        pass
+        for (k, v) in self.inclusion_table.items():
+            layer = self.get_layer(k)
+            for trait_name in v.keys():
+                print(trait_name)
+                trait = layer.get_trait(trait_name)
+                for layer_name in v[trait_name].keys():
+                    included_layer = self.get_layer(layer_name)
+                    included_traits = [
+                        included_layer.get_trait(x) 
+                        for x in v[trait_name][layer_name]
+                    ]
+                    print(included_layer, included_traits)
+                    for layer_included_trait in included_traits:
+                        trait.add_inclusion(layer_included_trait)
 
     def __exclusions__(self):
         for (k, v) in self.exclusion_table.items():
